@@ -11,20 +11,15 @@
 /// @author Baudouin Raoult
 /// @date   Jun 2020
 
-
 #include "metkit/codes/CodesContent.h"
-// #include "metkit/codes/MessageContent.h"
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/io/DataHandle.h"
 #include "eckit/io/MemoryHandle.h"
-// #include "metkit/mars/MarsRequest.h"
-// #include "metkit/codes/Decoder.h"
 
-#include "metkit/grib/GribHandle.h"
+#include "eckit/memory/Zero.h"
 
-
-#include "eccodes.h"
+#include "metkit/codes/GribHandle.h"
 
 namespace metkit {
 namespace codes {
@@ -110,6 +105,32 @@ void CodesContent::getDoubleArray(const std::string& key, std::vector<double>& v
     ASSERT(count == size);
 }
 
+eckit::message::MessageContent* CodesContent::transform(const eckit::StringDict& dict) const {
+    codes_handle* h = codes_handle_clone(handle_);
+
+    ASSERT(dict.size() <= 256);
+    codes_values values[256];
+    eckit::zero(values);
+    size_t i = 0;
+    for (auto& kv : dict) {
+        // eckit::Log::info() << "kv: key " << kv.first << " value " << kv.second << std::endl;
+        values[i].name         = kv.first.c_str();
+        values[i].string_value = kv.second.c_str();
+        values[i].type         = GRIB_TYPE_STRING;
+        i++;
+    }
+
+    try {
+        CODES_CALL(codes_set_values(h, values, i));
+    }
+    catch(...) {
+        codes_handle_delete(h);
+        throw;
+    }
+
+    return new CodesContent(h);
+}
+
 eckit::Offset CodesContent::offset() const {
     long pos;
     CODES_CALL(codes_get_long(handle_, "offset", &pos));
